SF_TOOLS
========

:Author: Samuel Farrens `(samuel.farrens@gmail.com) <samuel.farrens@gmail.com>`_

:Version: 1.0.1

:Date: 25/10/2017

:Documentation: |link-to-docs|

.. |link-to-docs| raw:: html

  <a href="https://sfarrens.github.io/sf_tools/"
  target="_blank">https://sfarrens.github.io/sf_tools/</a>

SF_TOOLS is a series of Python modules with applications to image analysis,
signal processing and statistics.

Contents
========

1. `Dependencies`_

   1. `Required Packages`_
   2. `Optional Packages`_

2. `Installation`_

Dependencies
============

Required Packages
-----------------

In order to run the code in this repository the following packages must be
installed:

* |link-to-python| [Tested with v 2.7.11 and 3.6.3]

* |link-to-numpy| [Tested with v 1.13.3]

* |link-to-scipy| [Tested with v 0.18.1]

* |link-to-future| [Tested with v 0.16.0]

* |link-to-astropy| [Tested with v 1.3]

.. |link-to-python| raw:: html

  <a href="https://www.python.org/"
  target="_blank">Python</a>

.. |link-to-numpy| raw:: html

  <a href="http://www.numpy.org/"
  target="_blank">Numpy</a>

.. |link-to-scipy| raw:: html

  <a href="http://www.scipy.org/"
  target="_blank">Scipy</a>

.. |link-to-future| raw:: html

  <a href="http://python-future.org/quickstart.html"
  target="_blank">Future</a>

.. |link-to-astropy| raw:: html

  <a href="http://www.astropy.org/"
  target="_blank">Astropy</a>

Optional Packages
-----------------

The following packages can optionally be installed to add extra functionality:

* |link-to-matplotlib| [Tested with v 2.0.2]

* |link-to-termcolor| [Tested with v 1.1.0]

.. |link-to-matplotlib| raw:: html

  <a href="http://matplotlib.org/"
  target="_blank">Matplotlib</a>

.. |link-to-termcolor| raw:: html

  <a href="https://pypi.python.org/pypi/termcolor"
  target="_blank">Termcolor</a>

Installation
============

To clone the sf_tools repository from GitHub run the following command:

.. code-block:: bash

  $ git clone https://github.com/sfarrens/sf_tools

To install using `easy_install` run the following command:

.. code-block:: bash

  $ easy_install sf_tools

To install using `pip` run the following command:

.. code-block:: bash

  $ pip install sf_tools
